@@ -9,6 +9,8 @@ options(digits = 5)
 
 x1 <- fracdiff.sim(5000, ar = .2, ma = -.4, d = .3, n.start=0, allow.0 = TRUE)
 (fd1 <- fracdiff(x1$series, nar = 1, nma = 1, dtol = 1e-10))
+vcov(fd1)
+logLik(fd1)
 
 fdCOVcomp <-
     c("h", "covariance.dpq", "stderror.dpq", "correlation.dpq", "hessian.dpq")
@@ -19,8 +21,10 @@ sapply(fd1u[fdCOVcomp], signif, digits = 4)
 
 ## 2)
 
-x2 <-  fracdiff.sim( 2048, ar = .8, ma = -.4, d = .3, n.start=0, allow.0 = TRUE)# -> NA's and problems
-(fd2 <- fracdiff(x2$series, nar = length(x2$ar), nma = length(x2$ma)))
+x2 <-  fracdiff.sim( 2048, ar = .8, ma = -.4, d = .3, n.start=0, allow.0 = TRUE)
+## -> NA's and problems
+fd2 <- fracdiff(x2$series, nar = length(x2$ar), nma = length(x2$ma))
+summary(fd2)
 
 fd2. <- fracdiff.var(x2$series, fd2, h = fd2$h / 2)
 sapply(fd2.[fdCOVcomp], signif, digits = 4)
